﻿using Hotline.Share.Dtos.Settings;
using Hotline.Share.Enums.FlowEngine;

namespace Hotline.Share.Dtos.FlowEngine;

public class NextStepsDto
{
    /// <summary>
    /// 当前办理节点
    /// </summary>
    public string StepId { get; set; }

    // public IReadOnlyList<NextStepOption> Steps { get; set; }
    public DateTime? ExpiredTime { get; set; }

    /// <summary>
    /// 是否有否决按钮
    /// </summary>
    public bool CanReject { get; set; }

    /// <summary>
    /// 是否支持发起会签
    /// </summary>
    public bool CanStartCountersign { get; set; }


    /// <summary>
    /// 是否显示主办对象
    /// </summary>
    public bool IsMainHandlerShow { get; set; }

    /// <summary>
    /// 当前办理节点业务类型
    /// </summary>
    public EBusinessType CurrentStepBusinessType { get; set; }

    /// <summary>
    /// 当前办理节点部门等级(非部门等级办理时无效)
    /// </summary>
    public int? CurrentOrgLevel { get; set; }

    public IReadOnlyList<KeyValuePair<int, string>> TimeTypeOptions { get; set; }

    /// <summary>
    /// 临时保存的办理意见
    /// </summary>
    public string? Opinion { get; set; }
}

public class NextStepsDto<TSteps> : NextStepsDto
{
    public List<TSteps> Steps { get; set; }
}

public class NextStepsWithOpinionDto<TSteps> : NextStepsDto<TSteps>
{
    /// <summary>
    /// 宜宾需求：汇总节点办理前展示前一节点办理意见
    /// 自贡需求: 临时保存的办理意见
    /// </summary>
    public string? Opinion { get; set; }

    /// <summary>
    /// 自贡需求: 选择某一部门后会给对应部门领导发短信
    /// </summary>
    public IList<Kv>? LeaderSMS { get; set; }

    /// <summary>
    /// 市州转办信息
    /// </summary>
    public List<SystemDicDataOutDto>? TranspondCity { get; set; }

    /// <summary>
    /// 会签类型：null：非会签，0：中心会签，1：部门会签
    /// </summary>
    public ECounterSignType? CounterSignType { get; set; }
}

public class StepTempInDto
{
    /// <summary>
    /// 工单Id
    /// </summary>
    public string OrderId { get; set; }

    /// <summary>
    /// 意见
    /// </summary>
    public string Opinion { get; set; }
}


