﻿using Hotline.Caching.Interfaces;
using Hotline.Settings;
using XF.Domain.Cache;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;
using XF.Domain.Repository;

namespace Hotline.Caching.Services
{
    public class SystemSettingCacheManager : ISystemSettingCacheManager, IScopeDependency
    {

        private readonly ITypedCache<SystemSetting> _cacheSystemSetting;
        private readonly IRepository<SystemSetting> _systemSettingRepository;

        public SystemSettingCacheManager(ITypedCache<SystemSetting> cacheSystemSetting, IRepository<SystemSetting> systemSettingRepository)
        {
            _cacheSystemSetting = cacheSystemSetting;
            _systemSettingRepository = systemSettingRepository;
        }

        public SystemSetting? GetSetting(string code)
        {
            var setting = _cacheSystemSetting.GetOrSet(code, x =>
            {
                var dbsetting = _systemSettingRepository.GetAsync(d => d.Code == code).GetAwaiter().GetResult();
                if (dbsetting == null)
                    throw new UserFriendlyException($"{code} 无效系统设置");
                return dbsetting;
            });
            return setting;
        }

        public void DelSystemSetting(string code)
        {
            _cacheSystemSetting.Remove(code);
        }

        public int EffectiveTimes
            => int.Parse(GetSetting(SettingConstants.EffectiveTimes)?.SettingValue[0]);

        public int ConnectByeTimes 
            => int.Parse(GetSetting(SettingConstants.ConnectByeTimes)?.SettingValue[0]);

        public int NoConnectByeTimes => int.Parse(GetSetting(SettingConstants.NoConnectByeTimes)?.SettingValue[0]);

        public int CallInOverConnRingTime => int.Parse(GetSetting(SettingConstants.CallInOverConnRingTime)?.SettingValue[0]);

        public int SeatChaoTime => int.Parse(GetSetting(SettingConstants.SeatChaoTime)?.SettingValue[0]);

        public int RingTimes => int.Parse(GetSetting(SettingConstants.RingTimes)?.SettingValue[0]);

        public string RecordPrefix => GetSetting(SettingConstants.RecordPrefix)?.SettingValue[0].Trim().ToString();

        public string DefaultVisitEmployeeId => GetSetting(SettingConstants.DefaultVisitEmployeeId)?.SettingValue[0].Trim().ToString();

        public int FixedQueryCount => int.Parse(GetSetting(SettingConstants.FixedQueryCount)?.SettingValue[0]);
    }
}
